@@ -53,7 +53,7 @@ def run_query_data() -> None:
         dimension=[DimensionType.Traffic],
         cidr=32,
         cidr6=128,
-        metric=MetricType.bytes,
+        metric=[MetricType.bytes],
         topx=8,
         depth=75,
         fastData=FastDataType.auto,
@@ -62,7 +62,6 @@ def run_query_data() -> None:
         hostname_lookup=True,
         device_name=[],
         all_selected=True,
-        filters_obj=None,
         descriptor="",
         aggregates=[agg1, agg2, agg3],
     )
@@ -92,7 +91,7 @@ def run_query_chart() -> None:
         dimension=[DimensionType.Traffic],
         cidr=32,
         cidr6=128,
-        metric=MetricType.bytes,
+        metric=[MetricType.bytes],
         topx=8,
         depth=75,
         fastData=FastDataType.auto,
@@ -106,7 +105,6 @@ def run_query_chart() -> None:
         device_name=[],
         matrixBy=[],
         all_selected=True,
-        filters_obj=None,
         descriptor="",
         aggregates=[agg1, agg2, agg3],
     )
@@ -134,7 +132,7 @@ def run_query_url() -> None:
         dimension=[DimensionType.Traffic],
         cidr=32,
         cidr6=128,
-        metric=MetricType.bytes,
+        metric=[MetricType.bytes],
         topx=8,
         depth=75,
         fastData=FastDataType.auto,
