@@ -15,8 +15,6 @@ from .api_resources.users_api import UsersAPI
 from typing import Optional, Tuple, Union
 from .api_connection.retryable_session import Retry
 
-# pylint: disable=too-many-instance-attributes
-
 
 class KentikAPI:
     """Root object for operating KentikAPI"""
@@ -31,8 +29,9 @@ class KentikAPI:
         api_url: str = API_URL_US,
         timeout: Union[float, Tuple[float, float]] = (10.0, 60.0),
         retry_strategy: Optional[Retry] = None,
+        proxy: Optional[str] = None,
     ) -> None:
-        connector = new_connector(api_url, auth_email, auth_token, timeout, retry_strategy)
+        connector = APIConnector(api_url, auth_email, auth_token, timeout, retry_strategy, proxy)
 
         self.device_labels = DeviceLabelsAPI(connector)
         self.sites = SitesAPI(connector)
@@ -50,13 +49,3 @@ class KentikAPI:
 
 
 # pylint: enable=too-many-instance-attributes
-
-
-def new_connector(
-    api_url: str,
-    auth_email: str,
-    auth_token: str,
-    timeout: Union[float, Tuple[float, float]],
-    retry_strategy: Optional[Retry],
-) -> APIConnector:
-    return APIConnector(api_url, auth_email, auth_token, timeout, retry_strategy)
