@@ -9,45 +9,47 @@ from .custom_application import CustomApplication
 from .plan import Plan, PlanDevice, PlanDeviceType
 from .batch_operation import BatchOperationPart, Upsert, Criterion, Deletion
 from .manual_mitigation import ManualMitigation, Alarm, HistoricalAlert, AlertFilter
-from .query_sql import QuerySQL
+from .query_sql import QuerySQL, QuerySQLResult
 from .query_object import (
-    QueryObject,
-    QueryArrayItem,
-    Query,
-    ImageType,
     Aggregate,
     AggregateFunctionType,
-    FastDataType,
-    MetricType,
-    DimensionType,
     ChartViewType,
+    DimensionType,
+    FastDataType,
+    ImageType,
+    MetricType,
+    Query,
+    QueryArrayItem,
+    QueryDataResult,
+    QueryObject,
     TimeFormat,
 )
 from .device import (
-    Device,
-    AuthenticationProtocol,
-    PrivacyProtocol,
-    CDNAttribute,
-    DeviceBGPType,
-    DeviceType,
-    DeviceSubtype,
-    SNMPv3Conf,
     AppliedLabels,
+    AuthenticationProtocol,
+    CDNAttribute,
+    Device,
+    DeviceBGPType,
+    DeviceInterface,
+    DeviceSubtype,
+    DeviceType,
     Interface,
-    TopNextHopASN,
+    PrivacyProtocol,
+    SNMPv3Conf,
     SecondaryIP,
+    TopNextHopASN,
     VRFAttributes,
 )
 from .errors import (
-    KentikAPIError,
-    ProtocolError,
     AuthError,
     BadRequestError,
     DataFormatError,
     DeserializationError,
     IncompleteObjectError,
     IntermittentError,
+    KentikAPIError,
     NotFoundError,
+    ProtocolError,
     RateLimitExceededError,
     TimedOutError,
     UnavailabilityError,
